@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,10 +38,7 @@ TemplateManager::TemplateManager(const QString &relativeTemplateDir, PimCommon::
     loadTemplates(true);
 }
 
-TemplateManager::~TemplateManager()
-{
-    delete d;
-}
+TemplateManager::~TemplateManager() = default;
 
 void TemplateManager::slotDirectoryChanged()
 {
@@ -67,7 +64,7 @@ void TemplateManager::loadTemplates(bool init)
 {
     if (!init) {
         if (!d->mTemplatesDirectories.isEmpty()) {
-            for (const QString &directory : qAsConst(d->mTemplatesDirectories)) {
+            for (const QString &directory : std::as_const(d->mTemplatesDirectories)) {
                 d->mDirWatch->removeDir(directory);
             }
         } else {
@@ -75,7 +72,7 @@ void TemplateManager::loadTemplates(bool init)
         }
     }
 
-    for (const QString &directory : qAsConst(d->mTemplatesDirectories)) {
+    for (const QString &directory : std::as_const(d->mTemplatesDirectories)) {
         QDirIterator dirIt(directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot);
         while (dirIt.hasNext()) {
             dirIt.next();
