@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,13 +8,9 @@
 #include "blacklistbalooemailutil.h"
 
 using namespace PimCommon;
-BlackListBalooEmailUtil::BlackListBalooEmailUtil()
-{
-}
+BlackListBalooEmailUtil::BlackListBalooEmailUtil() = default;
 
-BlackListBalooEmailUtil::~BlackListBalooEmailUtil()
-{
-}
+BlackListBalooEmailUtil::~BlackListBalooEmailUtil() = default;
 
 void BlackListBalooEmailUtil::initialBlackList(const QStringList &blackList)
 {
